@@ -26,7 +26,7 @@
 extern "C" {
 #endif
 
-#define LIBGNUTLS_VERSION "0.5.0"
+#define LIBGNUTLS_VERSION "0.5.1"
 
 #include <sys/types.h>
 #include <time.h>
@@ -294,7 +294,13 @@ int gnutls_dh_params_generate( gnutls_datum* prime, gnutls_datum* generator, int
 typedef ssize_t (*GNUTLS_PULL_FUNC)(GNUTLS_TRANSPORT_PTR, void*, size_t);
 typedef ssize_t (*GNUTLS_PUSH_FUNC)(GNUTLS_TRANSPORT_PTR, const void*, size_t);
 void gnutls_transport_set_ptr(GNUTLS_STATE state, GNUTLS_TRANSPORT_PTR ptr);
+void gnutls_transport_set_ptr2(GNUTLS_STATE state, GNUTLS_TRANSPORT_PTR recv_ptr,
+	GNUTLS_TRANSPORT_PTR send_ptr);
+
 GNUTLS_TRANSPORT_PTR gnutls_transport_get_ptr(GNUTLS_STATE state);
+void gnutls_transport_get_ptr2(GNUTLS_STATE state,
+	GNUTLS_TRANSPORT_PTR *recv_ptr,
+	GNUTLS_TRANSPORT_PTR *send_ptr);
 
 void gnutls_transport_set_lowat( GNUTLS_STATE state, int num);
 
@@ -507,6 +513,12 @@ int gnutls_b64_decode_fmt2( const gnutls_datum *b64_data, const gnutls_datum* re
 #define GNUTLS_E_UNKNOWN_PK_ALGORITHM -80
 #define GNUTLS_E_OPENPGP_TRUSTDB_VERSION_UNSUPPORTED -81
 
+/* returned if libextra functionality was requested but
+ * gnutls_global_init_extra() was not called.
+ */
+#define GNUTLS_E_INIT_LIBEXTRA -82
+#define GNUTLS_E_LIBRARY_VERSION_MISMATCH -82
+
 #define GNUTLS_E_UNIMPLEMENTED_FEATURE -250
 
 
