@@ -16,7 +16,12 @@
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with this library; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
- * */
+ * 
+ */
+
+/* This file contains the RSA key exchange part of the certificate
+ * authentication.
+ */
 
 #include "gnutls_int.h"
 #include "gnutls_auth_int.h"
@@ -90,7 +95,7 @@ int i;
 		case GNUTLS_CRT_OPENPGP:
 			if (_E_gnutls_openpgp_cert2gnutls_cert==NULL) {
 				gnutls_assert();
-				return GNUTLS_E_INVALID_REQUEST;
+				return GNUTLS_E_INIT_LIBEXTRA;
 			}
 			if ((ret =
 			     _E_gnutls_openpgp_cert2gnutls_cert( &peer_cert,
