@@ -51,7 +51,7 @@ static const gnutls_cred_map cred_mappings[] = {
 /* TLS Versions */
 
 typedef struct {
-	char *name;
+	const char *name;
 	GNUTLS_Version id;	/* gnutls internal version number */
 	int major;		/* defined by the protocol */
 	int minor;		/* defined by the protocol */
@@ -74,7 +74,7 @@ static const gnutls_version_entry sup_versions[] = {
 
 
 struct gnutls_cipher_entry {
-	char *name;
+	const char *name;
 	BulkCipherAlgorithm id;
 	size_t blocksize;
 	size_t keysize;
@@ -106,20 +106,17 @@ static const gnutls_cipher_entry algorithms[] = {
                         GNUTLS_LOOP( if(p->id == algorithm) { a; break; } )
 
 
-#define GNUTLS_HASH_ENTRY(name, hashsize) \
-	{ #name, name, hashsize }
-
 struct gnutls_hash_entry {
-	char *name;
+	const char *name;
 	MACAlgorithm id;
 	size_t digestsize;
 };
 typedef struct gnutls_hash_entry gnutls_hash_entry;
 
 static const gnutls_hash_entry hash_algorithms[] = {
-	GNUTLS_HASH_ENTRY(GNUTLS_MAC_SHA, 20),
-	GNUTLS_HASH_ENTRY(GNUTLS_MAC_MD5, 16),
-	GNUTLS_HASH_ENTRY(GNUTLS_MAC_NULL, 0),
+	{"SHA", GNUTLS_MAC_SHA, 20},
+	{"MD5", GNUTLS_MAC_MD5, 16},
+	{"NULL", GNUTLS_MAC_NULL, 0},
 	{0}
 };
 
@@ -136,7 +133,7 @@ static const gnutls_hash_entry hash_algorithms[] = {
 	{ #name, name, id }
 
 struct gnutls_compression_entry {
-	char *name;
+	const char *name;
 	CompressionMethod id;
 	int num; /* the number reserved in TLS for the specific compression method */
 };
@@ -195,7 +192,7 @@ gnutls_kx_algo_entry _gnutls_kx_algorithms[MAX_KX_ALGOS] = {
 	{ #name, {name}, block_algorithm, kx_algorithm, mac_algorithm, version }
 
 typedef struct {
-	char *name;
+	const char *name;
 	GNUTLS_CipherSuite id;
 	BulkCipherAlgorithm block_algorithm;
 	KXAlgorithm kx_algorithm;
@@ -427,11 +424,11 @@ inline int _gnutls_mac_priority(GNUTLS_STATE state, MACAlgorithm algorithm)
   **/
 const char *gnutls_mac_get_name( GNUTLS_MACAlgorithm algorithm)
 {
-	char *ret = NULL;
+	const char *ret = NULL;
 
 	/* avoid prefix */
 	GNUTLS_HASH_ALG_LOOP(ret =
-			     p->name + sizeof("GNUTLS_MAC_") - 1);
+			     p->name);
 
 	return ret;
 }
@@ -474,7 +471,7 @@ inline
   **/
 const char *gnutls_compression_get_name( GNUTLS_CompressionMethod algorithm)
 {
-	char *ret = NULL;
+	const char *ret = NULL;
 
 	/* avoid prefix */
 	GNUTLS_COMPRESSION_ALG_LOOP(ret =
@@ -558,7 +555,15 @@ int _gnutls_cipher_is_block(BulkCipherAlgorithm algorithm)
 
 }
 
-int _gnutls_cipher_get_key_size(BulkCipherAlgorithm algorithm)
+/**
+  * gnutls_cipher_get_key_size - Returns the length of the cipher's key size
+  * @algorithm: is an encryption algorithm
+  *
+  * Returns the length (in bytes) of the given cipher's key size.
+  * Returns 0 if the given cipher is invalid.
+  *
+  **/
+size_t gnutls_cipher_get_key_size( GNUTLS_BulkCipherAlgorithm algorithm)
 {				/* In bytes */
 	size_t ret = 0;
 	GNUTLS_ALG_LOOP(ret = p->keysize);
@@ -583,7 +588,7 @@ int _gnutls_cipher_get_iv_size(BulkCipherAlgorithm algorithm)
   **/
 const char *gnutls_cipher_get_name( GNUTLS_BulkCipherAlgorithm algorithm)
 {
-	char *ret = NULL;
+	const char *ret = NULL;
 
 	/* avoid prefix */
 	GNUTLS_ALG_LOOP(ret = p->name);
@@ -634,7 +639,7 @@ inline int _gnutls_kx_priority(GNUTLS_STATE state, KXAlgorithm algorithm)
   **/
 const char *gnutls_kx_get_name( GNUTLS_KXAlgorithm algorithm)
 {
-	char *ret = NULL;
+	const char *ret = NULL;
 
 	/* avoid prefix */
 	GNUTLS_KX_ALG_LOOP(ret = p->name);
@@ -720,7 +725,7 @@ GNUTLS_Version _gnutls_version_max(GNUTLS_STATE state)
   **/
 const char *gnutls_protocol_get_name( GNUTLS_Version version)
 {
-	char *ret = NULL;
+	const char *ret = NULL;
 
 	/* avoid prefix */
 	GNUTLS_VERSION_ALG_LOOP(ret =
@@ -826,7 +831,7 @@ _gnutls_cipher_suite_get_mac_algo(const GNUTLS_CipherSuite suite)
 
 const char *_gnutls_cipher_suite_get_name(GNUTLS_CipherSuite suite)
 {
-	char *ret = NULL;
+	const char *ret = NULL;
 
 	/* avoid prefix */
 	GNUTLS_CIPHER_SUITE_ALG_LOOP(ret =
@@ -840,7 +845,7 @@ inline
 static int _gnutls_cipher_suite_is_ok(GNUTLS_CipherSuite suite)
 {
 	size_t ret;
-	char *name = NULL;
+	const char *name = NULL;
 
 	GNUTLS_CIPHER_SUITE_ALG_LOOP(name = p->name);
 	if (name != NULL)
@@ -923,32 +928,34 @@ _gnutls_qsort(GNUTLS_STATE state, void *_base, size_t nmemb, size_t size,
 }
 
 
-/* a compare function for KX algorithms (using priorities). For use with qsort */
+/* a compare function for KX algorithms (using priorities). 
+ * For use with qsort 
+ */
 static int
 _gnutls_compare_algo(GNUTLS_STATE state, const void *i_A1,
 		     const void *i_A2)
 {
 	KXAlgorithm kA1 =
-	    _gnutls_cipher_suite_get_kx_algo(*(GNUTLS_CipherSuite *) i_A1);
+	    _gnutls_cipher_suite_get_kx_algo(*(const GNUTLS_CipherSuite *) i_A1);
 	KXAlgorithm kA2 =
-	    _gnutls_cipher_suite_get_kx_algo(*(GNUTLS_CipherSuite *) i_A2);
+	    _gnutls_cipher_suite_get_kx_algo(*(const GNUTLS_CipherSuite *) i_A2);
 	BulkCipherAlgorithm cA1 =
-	    _gnutls_cipher_suite_get_cipher_algo(*(GNUTLS_CipherSuite *)
+	    _gnutls_cipher_suite_get_cipher_algo(*(const GNUTLS_CipherSuite *)
 						 i_A1);
 	BulkCipherAlgorithm cA2 =
-	    _gnutls_cipher_suite_get_cipher_algo(*(GNUTLS_CipherSuite *)
+	    _gnutls_cipher_suite_get_cipher_algo(*(const GNUTLS_CipherSuite *)
 						 i_A2);
 	MACAlgorithm mA1 =
-	    _gnutls_cipher_suite_get_mac_algo(*(GNUTLS_CipherSuite *)
+	    _gnutls_cipher_suite_get_mac_algo(*(const GNUTLS_CipherSuite *)
 					      i_A1);
 	MACAlgorithm mA2 =
-	    _gnutls_cipher_suite_get_mac_algo(*(GNUTLS_CipherSuite *)
+	    _gnutls_cipher_suite_get_mac_algo(*(const GNUTLS_CipherSuite *)
 					      i_A2);
 
-	int p1 = (_gnutls_kx_priority(state, kA1) + 1) * 100;
-	int p2 = (_gnutls_kx_priority(state, kA2) + 1) * 100;
-	p1 += (_gnutls_cipher_priority(state, cA1) + 1) * 10;
-	p2 += (_gnutls_cipher_priority(state, cA2) + 1) * 10;
+	int p1 = (_gnutls_kx_priority(state, kA1) + 1) * 64;
+	int p2 = (_gnutls_kx_priority(state, kA2) + 1) * 64;
+	p1 += (_gnutls_cipher_priority(state, cA1) + 1) * 8;
+	p2 += (_gnutls_cipher_priority(state, cA2) + 1) * 8;
 	p1 += _gnutls_mac_priority(state, mA1);
 	p2 += _gnutls_mac_priority(state, mA2);
 
@@ -1055,6 +1062,12 @@ _gnutls_supported_ciphersuites(GNUTLS_STATE state,
 	}
 
 	for (i = j = 0; i < count; i++) {
+		/* remove private cipher suites, if requested.
+		 */
+		if ( state->gnutls_internals.enable_private == 0 &&
+			tmp_ciphers[i].CipherSuite[0] == 0xFF)
+				continue;
+
 		/* remove cipher suites which do not support the
 		 * protocol version used.
 		 */
@@ -1107,12 +1120,14 @@ _gnutls_supported_ciphersuites(GNUTLS_STATE state,
 
 /* For compression  */
 
+#define MIN_PRIVATE_COMP_ALGO 0x0F
+
 /* returns the TLS numbers of the compression methods we support */
 #define SUPPORTED_COMPRESSION_METHODS state->gnutls_internals.CompressionMethodPriority.algorithms
 int
 _gnutls_supported_compression_methods(GNUTLS_STATE state, uint8 ** comp)
 {
-	int i, tmp;
+	int i, tmp, j=0;
 
 	*comp = gnutls_malloc(SUPPORTED_COMPRESSION_METHODS);
 	if (*comp == NULL)
@@ -1122,16 +1137,21 @@ _gnutls_supported_compression_methods(GNUTLS_STATE state, uint8 ** comp)
 		tmp = _gnutls_compression_get_num(state->gnutls_internals.
 						  CompressionMethodPriority.
 						  algorithm_priority[i]);
-		if (tmp == -1) {
+		
+		/* remove private compression algorithms, if requested.
+		 */
+		if (tmp == -1 || (state->gnutls_internals.enable_private == 0 &&
+			tmp >= MIN_PRIVATE_COMP_ALGO)) {
+
 			gnutls_assert();
-			/* we shouldn't get here */
-			(*comp)[i] = 0;
 			continue;
 		}
-		(*comp)[i] = (uint8) tmp;
+
+		(*comp)[j] = (uint8) tmp;
+		j++;
 	}
 
-	return SUPPORTED_COMPRESSION_METHODS;
+	return j;
 }
 
 /**
@@ -1143,7 +1163,7 @@ _gnutls_supported_compression_methods(GNUTLS_STATE state, uint8 ** comp)
   **/
 const char *gnutls_cert_type_get_name( GNUTLS_CertificateType type)
 {
-	char *ret = NULL;
+	const char *ret = NULL;
 
 	if (type==GNUTLS_CRT_X509) ret = "X.509";
 	if (type==GNUTLS_CRT_OPENPGP) ret = "OPENPGP";
