@@ -19,6 +19,10 @@
  *
  */
 
+/* Some of the stuff needed for Certificate authentication is contained
+ * in this file.
+ */
+
 #include <gnutls_int.h>
 #include <gnutls_errors.h>
 #include <auth_cert.h>
@@ -352,7 +356,7 @@ int _gnutls_openpgp_cert_verify_peers(GNUTLS_STATE state)
 	 */
 	if (_E_gnutls_openpgp_verify_key==NULL) {
 		gnutls_assert();
-		return GNUTLS_E_INVALID_REQUEST;
+		return GNUTLS_E_INIT_LIBEXTRA;
 	}
 	verify = _E_gnutls_openpgp_verify_key( cred->pgp_trustdb, &cred->keyring, &info->raw_certificate_list[0],
 				      peer_certificate_list_size);
