@@ -23,17 +23,20 @@
 #include <gnutls_errors.h>
 #include <gnutls_num.h>
 
-void* (*gnutls_secure_malloc)(size_t) = malloc;
-void* (*gnutls_malloc)(size_t) = malloc;
-void (*gnutls_free)(void*) = free;
+ALLOC_FUNC gnutls_secure_malloc = malloc;
+ALLOC_FUNC gnutls_malloc = malloc;
+FREE_FUNC gnutls_free = free;
+REALLOC_FUNC gnutls_realloc = realloc;
+
+void* (*gnutls_calloc)(size_t, size_t) = calloc;
+char* (*gnutls_strdup)(const char*) = strdup;
 
 int _gnutls_is_secure_mem_null( const void* ign) { return 0; }
 
 int (*_gnutls_is_secure_memory)(const void*) = _gnutls_is_secure_mem_null;
-void* (*gnutls_realloc)(void*, size_t) = realloc;
 
 
-void *gnutls_calloc(size_t nmemb, size_t size)
+void *_gnutls_calloc(size_t nmemb, size_t size)
 {
 	void *ret;
 	ret = gnutls_malloc(size);
@@ -57,17 +60,16 @@ svoid *gnutls_secure_calloc(size_t nmemb, size_t size)
 	return ret;
 }
 
-char *gnutls_strdup(const char *s)
-{
-	int size = strlen(s);
-	char *ret;
+char* _gnutls_strdup( const char* str) {
+int siz = strlen( str);
+char * ret;
 
-	ret = gnutls_malloc(size + 1);	/* hold null */
+	ret = gnutls_malloc( siz + 1);
 	if (ret == NULL)
 		return ret;
-
-	strcpy(ret, s); /* Flawfinder: ignore */
-
+		
+	memcpy( ret, str, siz);
+	ret[ siz] = 0;
+	
 	return ret;
 }
-
