@@ -19,13 +19,17 @@
  *
  */
 
+/* Functions to manipulate the state (gnutls_int.h), and some other stuff
+ * are included here.
+ */
+
 #include <gnutls_int.h>
 #include <gnutls_errors.h>
 #include <gnutls_auth_int.h>
 #include <gnutls_priority.h>
 #include <gnutls_num.h>
-#include "gnutls_datum.h"
-#include "gnutls_db.h"
+#include <gnutls_datum.h>
+#include <gnutls_db.h>
 #include <gnutls_record.h>
 #include <gnutls_handshake.h>
 #include <gnutls_dh.h>
@@ -191,12 +195,17 @@ int default_protocol_list[] = { GNUTLS_TLS1, 0 };
 	 * the receive procedure slow.
 	 */
 	(*state)->gnutls_internals.record_recv_buffer.data = gnutls_malloc(INITIAL_RECV_BUFFER_SIZE);
+
+	/* set the socket pointers to -1;
+	 */
+	(*state)->gnutls_internals.transport_recv_ptr = -1;
+	(*state)->gnutls_internals.transport_send_ptr = -1;
 	
 	/* set the default maximum record size for TLS
 	 */
-	(*state)->security_parameters.max_record_size = DEFAULT_MAX_RECORD_SIZE;
+	(*state)->security_parameters.max_record_recv_size = DEFAULT_MAX_RECORD_SIZE;
+	(*state)->security_parameters.max_record_send_size = DEFAULT_MAX_RECORD_SIZE;
 
-	
 	/* everything else not initialized here is initialized
 	 * as NULL or 0. This is why calloc is used.
 	 */
@@ -206,13 +215,24 @@ int default_protocol_list[] = { GNUTLS_TLS1, 0 };
 	return 0;
 }
 
+/* returns RESUME_FALSE or RESUME_TRUE.
+ */
+int _gnutls_session_is_resumable( GNUTLS_STATE state) 
+{
+	return state->gnutls_internals.resumable;
+}
+
+
 /**
-  * gnutls_deinit - This function clears all buffers associated with the &state
+  * _gnutls_deinit - This function clears all buffers associated with the &state
   * @state: is a &GNUTLS_STATE structure.
   *
   * This function clears all buffers associated with the &state.
+  * The difference with gnutls_deinit() is that this function will not
+  * interfere with the session database.
+  *
   **/
-void gnutls_deinit(GNUTLS_STATE state)
+void _gnutls_deinit(GNUTLS_STATE state)
 {
 
 	if (state==NULL) return;
@@ -269,14 +289,37 @@ void gnutls_deinit(GNUTLS_STATE state)
 		state->gnutls_key = NULL;
 	}
 
-	_gnutls_free(state->gnutls_internals.db_name);
-
 	memset( state, 0, sizeof(struct GNUTLS_STATE_INT));
 	gnutls_free(state);
 
 	return;
 }
 
+/**
+  * gnutls_deinit - This function clears all buffers associated with the &state
+  * @state: is a &GNUTLS_STATE structure.
+  *
+  * This function clears all buffers associated with the &state.
+  * This function will also remove session data from the session database
+  * if the session was terminated abnormally.
+  *
+  **/
+void gnutls_deinit(GNUTLS_STATE state)
+{
+
+	if (state==NULL) return;
+	
+	/* If the session was terminated abnormally then remove
+	 * the session data.
+	 */
+	if (_gnutls_session_is_resumable(state)==RESUME_FALSE) {
+		gnutls_db_remove_session( state);
+	}
+
+	_gnutls_deinit( state);
+}
+
+
 int _gnutls_dh_get_prime_bits( GNUTLS_STATE state) {
 	return state->gnutls_internals.dh_prime_bits;
 }
