@@ -50,11 +50,11 @@ int gnutls_openpgp_fingerprint(
 
 int gnutls_openpgp_keyid(
     const gnutls_datum *cert,
-    uint32 *keyid );
+    unsigned char keyid[8] );
 
 int gnutls_openpgp_add_keyring_mem(
     gnutls_datum *keyring,
-    const char *data,
+    const opaque *data,
     size_t len );
 
 int gnutls_openpgp_add_keyring_file(
@@ -67,7 +67,8 @@ int gnutls_certificate_set_openpgp_keyring_file(
 
 int gnutls_certificate_set_openpgp_keyring_mem(
     GNUTLS_CERTIFICATE_CREDENTIALS c,
-    const char *file );
+    const opaque *data,
+    size_t dlen );    
 
 int gnutls_openpgp_get_key(
     gnutls_datum *key,
@@ -84,6 +85,10 @@ int gnutls_openpgp_recv_key(
     short port,
     uint32 keyid,
     gnutls_datum *key );
+
+int gnutls_openpgp_key_to_xml(
+    const gnutls_datum *cert,
+    gnutls_datum *xmlkey, int ext );
      
 /* internal */
 int _gnutls_openpgp_cert2gnutls_cert(
@@ -93,8 +98,8 @@ int _gnutls_openpgp_cert2gnutls_cert(
 int
 _gnutls_openpgp_request_key(
     gnutls_datum* ret, 
-	const GNUTLS_CERTIFICATE_CREDENTIALS cred,
+    const GNUTLS_CERTIFICATE_CREDENTIALS cred,
     opaque* key_fpr,
-	int key_fpr_size );
+    int key_fpr_size );
 
 #endif /*GNUTLS_OPENPGP_H*/
